@@ -1,6 +1,6 @@
 #include "Python.h"
 #include "kmerslib.h"
-#include <string.h>
+#include "string.h"
 static PyObject* kmerslib_core_makeFFPS(PyObject *self, PyObject *args){
 	std::string dir;
     int startk;
